# Step 02: Tese de Investimento (Strategist)

## Inputs
- analises/<ativo>/fundamentalista.md
- analises/<ativo>/quantitativa.md
- analises/<ativo>/macroeconomica.md

## Expected Outputs
- analises/<ativo>/tese-investimento.md

## Quality Gate
- [ ] Arquivo tese-investimento.md existe e tem mais de 200 bytes
- [ ] Contém recomendação clara (COMPRAR, MANTER ou VENDER)
- [ ] Contém seção de riscos
- [ ] Contém disclaimer sobre IA

## Veto Conditions
- Sem recomendação clara (nem COMPRAR, nem MANTER, nem VENDER)
- Sem seção de riscos
